﻿using System;
using UnityEngine;
using Windows.Kinect;

public class CoordinateMapperView : MonoBehaviour
{
	private ComputeBuffer DepthBuffer,
                          BodyIndexBuffer;

	private DepthSpacePoint[] DepthPoints;
	private byte[] BodyIndexPoints;
	
	void Start ()
	{
        CoordinateMapperManager CoordinateMapperManager = GameObject.Find("Managers").GetComponent<CoordinateMapperManager>();
		
        GetComponent<Renderer>().material.SetTexture("_MainTex", CoordinateMapperManager.ColorTexture);
        
        DepthBuffer = GenerateBuffer("depthCoordinates", sizeof(float) * 2, (DepthPoints = CoordinateMapperManager.DepthCoordinates));
        BodyIndexBuffer = GenerateBuffer("BodyIndexBuffer", sizeof(float), (BodyIndexPoints = CoordinateMapperManager.BodyIndexBuffer));
    }

    ComputeBuffer GenerateBuffer(string name, int stride, Array points)
    {
        var buffer = new ComputeBuffer(points.Length, stride);
        GetComponent<Renderer>().material.SetBuffer(name, buffer);
        return buffer;
    }

	void Update()
	{
		//TODO: fix perf on this call.
		DepthBuffer.SetData(DepthPoints);
        
		BodyIndexBuffer.SetData(System.Array.ConvertAll(BodyIndexPoints, System.Convert.ToSingle));
	}
	
	void OnDisable() 
	{
        DepthBuffer.Release();   
        BodyIndexBuffer.Release();
    }
}
